@@ -210,12 +210,11 @@ is_online (ExchangeData *ed)
 }
 
 static void
-set_exception (CamelException *ex, const gchar *err)
+set_exception (GError **error, const gchar *err)
 {
 	g_return_if_fail (err != NULL);
 
-	if (ex && !camel_exception_is_set (ex))
-		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, err);
+	g_set_error (error, CAMEL_ERROR, CAMEL_ERROR_GENERIC, "%s", err);
 }
 
 static CamelFolder *
@@ -400,7 +399,7 @@ change_flags (ExchangeFolder *mfld, CamelFolder *folder, ExchangeMessage *mmsg,
 }
 
 static void
-refresh_folder_internal (ExchangeFolder *mfld, CamelException *ex)
+refresh_folder_internal (ExchangeFolder *mfld, GError **error)
 {
 	static const gchar *new_message_props[] = {
 		E2K_PR_REPL_UID,
@@ -527,7 +526,7 @@ refresh_folder_internal (ExchangeFolder *mfld, CamelException *ex)
 
 	if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status)) {
 		g_warning ("got_new_smtp_messages: %d", status);
-		set_exception (ex, _("Could not get new messages"));
+		set_exception (error, _("Could not get new messages"));
 		goto done;
 	}
 
@@ -566,7 +565,7 @@ refresh_folder_internal (ExchangeFolder *mfld, CamelException *ex)
 
 	if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status)) {
 		g_warning ("got_new_mapi_messages: %d", status);
-		set_exception (ex, _("Could not get new messages"));
+		set_exception (error, _("Could not get new messages"));
 		goto done;
 	}
 
@@ -760,7 +759,7 @@ sync_deletions (ExchangeFolder *mfld)
 		g_warning ("synced_deleted: %d", status);
 
 	/* Clear out removed messages from mfld */
-	for (my_i = mfld->messages->len - 1; my_i >= 0; my_i --) {
+	for (my_i = mfld->messages->len - 1; my_i >= 0; my_i--) {
 		mmsg = mfld->messages->pdata[my_i];
 		if (!g_hash_table_lookup (known_messages, mmsg)) {
 			mfld->deleted_count++;
@@ -821,9 +820,9 @@ free_folder (gpointer value)
 }
 
 static void
-got_folder_error (ExchangeFolder *mfld, CamelException *ex, const gchar *err)
+got_folder_error (ExchangeFolder *mfld, GError **error, const gchar *err)
 {
-	set_exception (ex, err);
+	set_exception (error, err);
 
 	free_folder (mfld);
 }
@@ -868,7 +867,7 @@ mfld_get_folder_online_sync_updates (gpointer key, gpointer value, gpointer user
 }
 
 static gboolean
-get_folder_contents_online (ExchangeFolder *mfld, CamelException *ex)
+get_folder_contents_online (ExchangeFolder *mfld, GError **error)
 {
 	static const gchar *open_folder_sync_props[] = {
 		E2K_PR_REPL_UID,
@@ -1054,7 +1053,7 @@ get_folder_contents_online (ExchangeFolder *mfld, CamelException *ex)
 	status = e2k_result_iter_free (iter);
 	if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status)) {
 		g_warning ("got_folder: %d", status);
-		got_folder_error (mfld, ex, _("Could not open folder"));
+		got_folder_error (mfld, error, _("Could not open folder"));
 		return FALSE;
 	}
 
@@ -1181,7 +1180,7 @@ notify_cb (E2kContext *ctx, const gchar *uri, E2kContextChangeType type, gpointe
 }
 
 static gboolean
-get_folder_online (ExchangeFolder *mfld, CamelException *ex)
+get_folder_online (ExchangeFolder *mfld, GError **error)
 {
 	static const gchar *open_folder_props[] = {
 		PR_ACCESS,
@@ -1201,11 +1200,11 @@ get_folder_online (ExchangeFolder *mfld, CamelException *ex)
 					     G_N_ELEMENTS (open_folder_props),
 					     &results, &nresults);
 	if (status == E2K_HTTP_UNAUTHORIZED) {
-		got_folder_error (mfld, ex, _("Could not open folder: Permission denied"));
+		got_folder_error (mfld, error, _("Could not open folder: Permission denied"));
 		return FALSE;
 	} else if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status)) {
 		g_warning ("got_folder_props: %d", status);
-		got_folder_error (mfld, ex, _("Could not open folder"));
+		got_folder_error (mfld, error, _("Could not open folder"));
 		return FALSE;
 	}
 
@@ -1219,7 +1218,7 @@ get_folder_online (ExchangeFolder *mfld, CamelException *ex)
 		mfld->access = ~0;
 
 	if (!(mfld->access & MAPI_ACCESS_READ)) {
-		got_folder_error (mfld, ex, _("Could not open folder: Permission denied"));
+		got_folder_error (mfld, error, _("Could not open folder: Permission denied"));
 		if (nresults)
 			e2k_results_free (results, nresults);
 		return FALSE;
@@ -1238,7 +1237,7 @@ get_folder_online (ExchangeFolder *mfld, CamelException *ex)
 	   change the PR_LAST_MODIFICATION_TIME property of a message.
 	*/
 	if (g_hash_table_size (mfld->messages_by_href) < 1) {
-		if (!get_folder_contents_online (mfld, ex))
+		if (!get_folder_contents_online (mfld, error))
 			return FALSE;
 	} else {
 		/* FIXME: Pass a GError and handle the error */
@@ -1262,13 +1261,13 @@ get_folder_online (ExchangeFolder *mfld, CamelException *ex)
 }
 
 static ExchangeFolder *
-folder_from_name (ExchangeData *ed, const gchar *folder_name, guint32 perms, CamelException *ex)
+folder_from_name (ExchangeData *ed, const gchar *folder_name, guint32 perms, GError **error)
 {
 	ExchangeFolder *mfld;
 
 	mfld = g_hash_table_lookup (ed->folders_by_name, folder_name);
 	if (!mfld) {
-		set_exception (ex, _("No such folder"));
+		set_exception (error, _("No such folder"));
 		return NULL;
 	}
 
@@ -1290,7 +1289,7 @@ folder_from_name (ExchangeData *ed, const gchar *folder_name, guint32 perms, Cam
 	}
 
 	if (perms && !(mfld->access & perms)) {
-		set_exception (ex, _("Permission denied"));
+		set_exception (error, _("Permission denied"));
 		return NULL;
 	}
 
@@ -2077,7 +2076,7 @@ struct update_linestatus
 {
 	CamelExchangeStore *estore;
 	gint linestatus;
-	CamelException *ex;
+	GError **error;
 };
 
 static void
@@ -2092,7 +2091,7 @@ folder_update_linestatus (gpointer key, gpointer value, gpointer data)
 	if (ul->linestatus == ONLINE_MODE) {
 		CamelFolder *folder;
 
-		get_folder_online (mfld, ul->ex);
+		get_folder_online (mfld, ul->error);
 
 		readonly = (mfld->access & (MAPI_ACCESS_MODIFY | MAPI_ACCESS_CREATE_CONTENTS)) ? 0 : 1;
 
@@ -2109,7 +2108,7 @@ gboolean
 camel_exchange_utils_connect (CamelService *service,
 				const gchar *pwd,
 				guint32 *status, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeAccount *account;
@@ -2156,7 +2155,7 @@ camel_exchange_utils_connect (CamelService *service,
 	   the first time */
 
 	ul.estore = ed->estore;
-	ul.ex = ex;
+	ul.error = error;
 	g_hash_table_foreach (ed->folders_by_name,
 			      (GHFunc) folder_update_linestatus,
 			      &ul);
@@ -2177,7 +2176,7 @@ camel_exchange_utils_get_folder (CamelService *service,
 				guint32 *folder_flags, /* out */
 				gchar **folder_uri, /* out */
 				gboolean *readonly, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -2197,7 +2196,7 @@ camel_exchange_utils_get_folder (CamelService *service,
 	path = g_strdup_printf ("/%s", name);
 	folder = exchange_account_get_folder (ed->account, path);
 	if (!folder && !create) {
-		set_exception (ex, _("No such folder"));
+		set_exception (error, _("No such folder"));
 		g_free (path);
 		return FALSE;
 	} else if (!folder) {
@@ -2206,7 +2205,7 @@ camel_exchange_utils_get_folder (CamelService *service,
 		result = exchange_account_create_folder (ed->account, path, "mail");
 		folder = exchange_account_get_folder (ed->account, path);
 		if (result != EXCHANGE_ACCOUNT_FOLDER_OK || !folder) {
-			set_exception (ex, _("Could not create folder."));
+			set_exception (error, _("Could not create folder."));
 			g_free (path);
 			return FALSE;
 		}
@@ -2254,9 +2253,8 @@ camel_exchange_utils_get_folder (CamelService *service,
 	mfld->high_article_num = high_article_num;
 
 	if (is_online (ed) == ONLINE_MODE) {
-		if (!get_folder_online (mfld, ex)) {
+		if (!get_folder_online (mfld, error))
 			return FALSE;
-		}
 	}
 	g_signal_connect (mfld->folder, "changed",
 			  G_CALLBACK (storage_folder_changed), mfld);
@@ -2287,7 +2285,7 @@ camel_exchange_utils_get_folder (CamelService *service,
 gboolean
 camel_exchange_utils_get_trash_name (CamelService *service,
 				gchar **trash_name, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 
@@ -2295,7 +2293,7 @@ camel_exchange_utils_get_trash_name (CamelService *service,
 	g_return_val_if_fail (trash_name != NULL, FALSE);
 
 	if (!ed->deleted_items) {
-		set_exception (ex, _("Could not open Deleted Items folder"));
+		set_exception (error, _("Could not open Deleted Items folder"));
 		return FALSE;
 	}
 
@@ -2307,19 +2305,18 @@ camel_exchange_utils_get_trash_name (CamelService *service,
 gboolean
 camel_exchange_utils_refresh_folder (CamelService *service,
 				const gchar *folder_name,
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
 
 	g_return_val_if_fail (ed != NULL, FALSE);
 
-	mfld = folder_from_name (ed, folder_name, 0, ex);
-	if (!mfld) {
+	mfld = folder_from_name (ed, folder_name, 0, error);
+	if (!mfld)
 		return FALSE;
-	}
 
-	refresh_folder_internal (mfld, ex);
+	refresh_folder_internal (mfld, NULL);
 	sync_deletions (mfld);
 
 	return TRUE;
@@ -2330,7 +2327,7 @@ camel_exchange_utils_sync_count (CamelService *service,
 				const gchar *folder_name,
 				guint32 *unread_count, /* out */
 				guint32 *visible_count, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -2339,7 +2336,7 @@ camel_exchange_utils_sync_count (CamelService *service,
 	g_return_val_if_fail (unread_count != NULL, FALSE);
 	g_return_val_if_fail (visible_count != NULL, FALSE);
 
-	mfld = folder_from_name (ed, folder_name, 0, ex);
+	mfld = folder_from_name (ed, folder_name, 0, error);
 	if (mfld) {
 		*unread_count = mfld->unread_count;
 		*visible_count = mfld->messages->len;
@@ -2355,7 +2352,7 @@ gboolean
 camel_exchange_utils_expunge_uids (CamelService *service,
 				const gchar *folder_name,
 				GPtrArray *uids,
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -2373,7 +2370,7 @@ camel_exchange_utils_expunge_uids (CamelService *service,
 	if (!uids->len)
 		return TRUE;
 
-	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_DELETE, ex);
+	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_DELETE, error);
 	if (!mfld)
 		return FALSE;
 
@@ -2422,9 +2419,9 @@ camel_exchange_utils_expunge_uids (CamelService *service,
 	if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status)) {
 		g_warning ("expunged: %d", status);
 		some_error = TRUE;
-		set_exception (ex, _("Could not empty Deleted Items folder"));
+		set_exception (error, _("Could not empty Deleted Items folder"));
 	} else if (some_error) {
-		set_exception (ex, _("Permission denied. Could not delete certain messages."));
+		set_exception (error, _("Permission denied. Could not delete certain messages."));
 	}
 
 	g_ptr_array_free (hrefs, TRUE);
@@ -2445,7 +2442,7 @@ camel_exchange_utils_append_message (CamelService *service,
 				const gchar *subject,
 				const GByteArray *message,
 				gchar **new_uid, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -2456,7 +2453,8 @@ camel_exchange_utils_append_message (CamelService *service,
 	g_return_val_if_fail (new_uid != NULL, FALSE);
 	g_return_val_if_fail (message != NULL, FALSE);
 
-	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_CREATE_CONTENTS, ex);
+	mfld = folder_from_name (
+		ed, folder_name, MAPI_ACCESS_CREATE_CONTENTS, error);
 	if (!mfld)
 		return FALSE;
 
@@ -2466,7 +2464,7 @@ camel_exchange_utils_append_message (CamelService *service,
 					    &location, &ru_header);
 	if (status != E2K_HTTP_CREATED) {
 		g_warning ("appended_message: %d", status);
-		set_exception (ex, status == E2K_HTTP_INSUFFICIENT_SPACE_ON_RESOURCE ?
+		set_exception (error, status == E2K_HTTP_INSUFFICIENT_SPACE_ON_RESOURCE ?
 				   _("Could not append message; mailbox is over quota") :
 				   _("Could not append message"));
 		return FALSE;
@@ -2522,7 +2520,7 @@ camel_exchange_utils_set_message_flags (CamelService *service,
 					const gchar *uid,
 					guint32 flags,
 					guint32 mask,
-					CamelException *ex)
+					GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -2530,7 +2528,7 @@ camel_exchange_utils_set_message_flags (CamelService *service,
 
 	g_return_val_if_fail (ed != NULL, FALSE);
 
-	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_MODIFY, ex);
+	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_MODIFY, error);
 	if (!mfld)
 		return FALSE;
 
@@ -2598,7 +2596,7 @@ camel_exchange_utils_set_message_tag (CamelService *service,
 				const gchar *uid,
 				const gchar *name,
 				const gchar *value,
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -2606,7 +2604,7 @@ camel_exchange_utils_set_message_tag (CamelService *service,
 
 	g_return_val_if_fail (ed != NULL, FALSE);
 
-	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_MODIFY, ex);
+	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_MODIFY, error);
 	if (!mfld)
 		return FALSE;
 
@@ -2626,7 +2624,7 @@ camel_exchange_utils_get_message (CamelService *service,
 				const gchar *folder_name,
 				const gchar *uid,
 				GByteArray **message_bytes, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -2641,7 +2639,7 @@ camel_exchange_utils_get_message (CamelService *service,
 	g_return_val_if_fail (ed != NULL, FALSE);
 	g_return_val_if_fail (message_bytes != NULL, FALSE);
 
-	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_READ, ex);
+	mfld = folder_from_name (ed, folder_name, MAPI_ACCESS_READ, error);
 	if (!mfld)
 		return FALSE;
 
@@ -2654,7 +2652,7 @@ camel_exchange_utils_get_message (CamelService *service,
 			camel_exchange_folder_remove_message (CAMEL_EXCHANGE_FOLDER (folder), uid);
 		}
 
-		set_exception (ex, _("No such message"));
+		set_exception (error, _("No such message"));
 		return FALSE;
 	}
 
@@ -2726,9 +2724,9 @@ camel_exchange_utils_get_message (CamelService *service,
 		 * time we recorded that.
 		 */
 		message_removed (mfld, folder, mmsg->href);
-		set_exception (ex, _("Message has been deleted"));
+		set_exception (error, _("Message has been deleted"));
 	} else
-		set_exception (ex, _("Error retrieving message"));
+		set_exception (error, _("Error retrieving message"));
 
  cleanup:
 	g_free (body);
@@ -2743,7 +2741,7 @@ camel_exchange_utils_search (CamelService *service,
 				const gchar *folder_name,
 				const gchar *text,
 				GPtrArray **found_uids, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -2757,7 +2755,7 @@ camel_exchange_utils_search (CamelService *service,
 	g_return_val_if_fail (ed != NULL, FALSE);
 	g_return_val_if_fail (found_uids != NULL, FALSE);
 
-	mfld = folder_from_name (ed, folder_name, 0, ex);
+	mfld = folder_from_name (ed, folder_name, 0, error);
 	if (!mfld)
 		return FALSE;
 
@@ -2777,7 +2775,7 @@ camel_exchange_utils_search (CamelService *service,
 	status = e2k_result_iter_free (iter);
 
 	if (status == E2K_HTTP_UNPROCESSABLE_ENTITY) {
-		set_exception (ex, _("Mailbox does not support full-text searching"));
+		set_exception (error, _("Mailbox does not support full-text searching"));
 
 		g_ptr_array_foreach (matches, (GFunc) g_free, NULL);
 		g_ptr_array_free (matches, TRUE);
@@ -2796,7 +2794,7 @@ camel_exchange_utils_transfer_messages (CamelService *service,
 					GPtrArray *uids,
 					gboolean delete_originals,
 					GPtrArray **ret_uids, /* out */
-					CamelException *ex)
+					GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *source, *dest;
@@ -2814,10 +2812,14 @@ camel_exchange_utils_transfer_messages (CamelService *service,
 	g_return_val_if_fail (ed != NULL, FALSE);
 	g_return_val_if_fail (ret_uids != NULL, FALSE);
 
-	source = folder_from_name (ed, source_name, delete_originals ? MAPI_ACCESS_DELETE : 0, ex);
+	source = folder_from_name (
+		ed, source_name, delete_originals ?
+		MAPI_ACCESS_DELETE : 0, error);
 	if (!source)
 		return FALSE;
-	dest = folder_from_name (ed, dest_name, MAPI_ACCESS_CREATE_CONTENTS, ex);
+
+	dest = folder_from_name (
+		ed, dest_name, MAPI_ACCESS_CREATE_CONTENTS, error);
 	if (!dest)
 		return FALSE;
 
@@ -2885,7 +2887,7 @@ camel_exchange_utils_transfer_messages (CamelService *service,
 		*ret_uids = new_uids;
 	} else {
 		g_warning ("transferred_messages: %d", status);
-		set_exception (ex, _("Unable to move/copy messages"));
+		set_exception (error, _("Unable to move/copy messages"));
 		g_ptr_array_free (new_uids, TRUE);
 		new_uids = NULL;
 	}
@@ -2954,7 +2956,7 @@ camel_exchange_utils_get_folder_info (CamelService *service,
 					GPtrArray **folder_uris, /* out */
 					GArray **unread_counts, /* out */
 					GArray **folder_flags, /* out */
-					CamelException *ex)
+					GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	GHashTable *known_uris;
@@ -2995,7 +2997,7 @@ camel_exchange_utils_send_message (CamelService *service,
 				const gchar *from,
 				GPtrArray *recipients,
 				const GByteArray *message,
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	SoupMessage *msg;
@@ -3013,7 +3015,7 @@ camel_exchange_utils_send_message (CamelService *service,
 	g_return_val_if_fail (ed->estore != NULL, FALSE);
 
 	if (!ed->mail_submission_uri) {
-		set_exception (ex, _("No mail submission URI for this mailbox"));
+		set_exception (error, _("No mail submission URI for this mailbox"));
 		return FALSE;
 	}
 
@@ -3046,12 +3048,12 @@ camel_exchange_utils_send_message (CamelService *service,
 	if (E2K_HTTP_STATUS_IS_SUCCESSFUL (status)) {
 		res = TRUE;
 	} else if (status == E2K_HTTP_NOT_FOUND) {
-		set_exception (ex, _("Server won't accept mail via Exchange transport"));
+		set_exception (error, _("Server won't accept mail via Exchange transport"));
 	} else if (status == E2K_HTTP_FORBIDDEN) {
 		errmsg = g_strdup_printf (_("Your account does not have permission "
 					    "to use <%s>\nas a From address."),
 					  from);
-		set_exception (ex, errmsg);
+		set_exception (error, errmsg);
 		g_free (errmsg);
 	} else if (status == E2K_HTTP_INSUFFICIENT_SPACE_ON_RESOURCE ||
 		   status == E2K_HTTP_INTERNAL_SERVER_ERROR) {
@@ -3060,11 +3062,11 @@ camel_exchange_utils_send_message (CamelService *service,
 		 * changes in the future.)
 		 */
 		E2K_KEEP_PRECEDING_COMMENT_OUT_OF_PO_FILES;
-		set_exception (ex, _("Could not send message.\n"
+		set_exception (error, _("Could not send message.\n"
 				     "This might mean that your account is over quota."));
 	} else {
 		g_warning ("sent_message: %d", status);
-		set_exception (ex, _("Could not send message"));
+		set_exception (error, _("Could not send message"));
 	}
 
 	return res;
@@ -3077,7 +3079,7 @@ camel_exchange_utils_create_folder (CamelService *service,
 				gchar **folder_uri, /* out */
 				guint32 *unread_count, /* out */
 				guint32 *flags, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeAccountFolderResult result;
@@ -3100,15 +3102,15 @@ camel_exchange_utils_create_folder (CamelService *service,
 			break;
 		/* fall through */
 	default:
-		set_exception (ex, _("Generic error"));
+		set_exception (error, _("Generic error"));
 		return FALSE;
 
 	case EXCHANGE_ACCOUNT_FOLDER_ALREADY_EXISTS:
-		set_exception (ex, _("Folder already exists"));
+		set_exception (error, _("Folder already exists"));
 		return FALSE;
 
 	case EXCHANGE_ACCOUNT_FOLDER_PERMISSION_DENIED:
-		set_exception (ex, _("Permission denied"));
+		set_exception (error, _("Permission denied"));
 		return FALSE;
 	}
 
@@ -3122,7 +3124,7 @@ camel_exchange_utils_create_folder (CamelService *service,
 gboolean
 camel_exchange_utils_delete_folder (CamelService *service,
 				const gchar *folder_name,
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeAccountFolderResult result;
@@ -3134,7 +3136,7 @@ camel_exchange_utils_delete_folder (CamelService *service,
 	path = g_build_filename ("/", folder_name, NULL);
 	folder = exchange_account_get_folder (ed->account, path);
 	if (!folder) {
-		set_exception (ex, _("Folder doesn't exist"));
+		set_exception (error, _("Folder doesn't exist"));
 		g_free (path);
 		return FALSE;
 	}
@@ -3151,12 +3153,12 @@ camel_exchange_utils_delete_folder (CamelService *service,
 
 	case EXCHANGE_ACCOUNT_FOLDER_PERMISSION_DENIED: /* Fall through */
 	case EXCHANGE_ACCOUNT_FOLDER_UNSUPPORTED_OPERATION:
-		set_exception (ex, _("Permission denied"));
+		set_exception (error, _("Permission denied"));
 		g_object_unref (folder);
 		return FALSE;
 
 	default:
-		set_exception (ex, _("Generic error"));
+		set_exception (error, _("Generic error"));
 		g_object_unref (folder);
 		return FALSE;
 
@@ -3175,7 +3177,7 @@ camel_exchange_utils_rename_folder (CamelService *service,
 				GPtrArray **folder_uris, /* out */
 				GArray **unread_counts, /* out */
 				GArray **folder_flags, /* out */
-				CamelException *ex)
+				GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeFolder *mfld;
@@ -3198,7 +3200,7 @@ camel_exchange_utils_rename_folder (CamelService *service,
 	old_path = g_build_filename ("/", old_name, NULL);
 	folder = exchange_account_get_folder (ed->account, old_path);
 	if (!folder) {
-		set_exception (ex, _("Folder doesn't exist"));
+		set_exception (error, _("Folder doesn't exist"));
 		g_free (old_path);
 		return FALSE;
 	}
@@ -3237,9 +3239,8 @@ camel_exchange_utils_rename_folder (CamelService *service,
 		}
 
 		if (is_online (ed) == ONLINE_MODE) {
-			if (!get_folder_online (mfld, ex)) {
+			if (!get_folder_online (mfld, error))
 				return FALSE;
-			}
 		}
 
 		for (i = 0; i < uris->len; i++) {
@@ -3299,9 +3300,8 @@ camel_exchange_utils_rename_folder (CamelService *service,
 			}
 
 			if (is_online (ed) == ONLINE_MODE) {
-				if (!get_folder_online (mfld, ex)) {
+				if (!get_folder_online (mfld, error))
 					return FALSE;
-				}
 			}
 
 			g_free (old_path);
@@ -3318,15 +3318,15 @@ camel_exchange_utils_rename_folder (CamelService *service,
 		break;
 
 	case EXCHANGE_ACCOUNT_FOLDER_DOES_NOT_EXIST:
-		set_exception (ex, _("Folder doesn't exist"));
+		set_exception (error, _("Folder doesn't exist"));
 		return FALSE;
 
 	case EXCHANGE_ACCOUNT_FOLDER_PERMISSION_DENIED:
-		set_exception (ex, _("Permission denied"));
+		set_exception (error, _("Permission denied"));
 		return FALSE;
 
 	default:
-		set_exception (ex, _("Generic error"));
+		set_exception (error, _("Generic error"));
 		return FALSE;
 
 	}
@@ -3337,7 +3337,7 @@ camel_exchange_utils_rename_folder (CamelService *service,
 gboolean
 camel_exchange_utils_subscribe_folder (CamelService *service,
 					const gchar *folder_name,
-					CamelException *ex)
+					GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeAccountFolderResult result;
@@ -3349,7 +3349,7 @@ camel_exchange_utils_subscribe_folder (CamelService *service,
 	path = g_build_filename ("/", folder_name, NULL);
 	folder = exchange_account_get_folder (ed->account, path);
 	if (!folder) {
-		set_exception (ex, _("Folder doesn't exist"));
+		set_exception (error, _("Folder doesn't exist"));
 		g_free (path);
 		return FALSE;
 	}
@@ -3375,11 +3375,11 @@ camel_exchange_utils_subscribe_folder (CamelService *service,
 		break;
 
 	case EXCHANGE_ACCOUNT_FOLDER_PERMISSION_DENIED:
-		set_exception (ex, _("Permission denied"));
+		set_exception (error, _("Permission denied"));
 		return FALSE;
 
 	default:
-		set_exception (ex, _("Generic error"));
+		set_exception (error, _("Generic error"));
 		return FALSE;
 	}
 
@@ -3389,7 +3389,7 @@ camel_exchange_utils_subscribe_folder (CamelService *service,
 gboolean
 camel_exchange_utils_unsubscribe_folder (CamelService *service,
 					const gchar *folder_name,
-					CamelException *ex)
+					GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	ExchangeAccountFolderResult result;
@@ -3401,7 +3401,7 @@ camel_exchange_utils_unsubscribe_folder (CamelService *service,
 	path = g_build_filename ("/", folder_name, NULL);
 	folder = exchange_account_get_folder (ed->account, path);
 	if (!folder) {
-		set_exception (ex, _("Folder doesn't exist"));
+		set_exception (error, _("Folder doesn't exist"));
 		g_free (path);
 		return FALSE;
 	}
@@ -3422,7 +3422,7 @@ camel_exchange_utils_unsubscribe_folder (CamelService *service,
 	path = g_build_filename ("/favorites", pub_name, NULL);
 	folder = exchange_account_get_folder (ed->account, path);
 	if (!folder) {
-		set_exception (ex, _("Folder doesn't exist"));
+		set_exception (error, _("Folder doesn't exist"));
 		g_free (path);
 		return FALSE;
 	}
@@ -3437,13 +3437,13 @@ camel_exchange_utils_unsubscribe_folder (CamelService *service,
 		break;
 
 	case EXCHANGE_ACCOUNT_FOLDER_PERMISSION_DENIED:
-		set_exception (ex, _("Permission denied"));
+		set_exception (error, _("Permission denied"));
 		g_object_unref (folder);
 		g_free (path);
 		return FALSE;
 
 	default:
-		set_exception (ex, _("Generic error"));
+		set_exception (error, _("Generic error"));
 		g_object_unref (folder);
 		g_free (path);
 		return FALSE;
@@ -3460,7 +3460,7 @@ gboolean
 camel_exchange_utils_is_subscribed_folder (CamelService *service,
 					const gchar *folder_name,
 					gboolean *is_subscribed, /* out */
-					CamelException *ex)
+					GError **error)
 {
 	ExchangeData *ed = get_data_for_service (service);
 	EFolder *folder;
